@@ -685,7 +685,7 @@ import inspect
 from distutils.version import StrictVersion
 
 # setup.py assumes the version is a simple string in '' quotes
-__version__ = '0.31'
+__version__ = '0.34'
 
 def _product(l):
     r'''Returns product of all values in the given list'''
@@ -1633,9 +1633,13 @@ def glue(*args, **kwargs):
     #      accum = nps.glue(accum, x,  axis = -2)
     #
     # Without special logic, this would throw an error since accum.shape starts
-    # at (0,), which is almost certainly not compatible with x.shape
-    if len(args) == 2 and args[0].shape == (0,) and args[1].size != 0:
-        return args[1]
+    # at (0,), which is almost certainly not compatible with x.shape. I support
+    # both glue(empty,x) and glue(x,empty)
+    if len(args) == 2:
+        if args[0].shape == (0,) and args[1].size != 0:
+            return atleast_dims(args[1], axis)
+        if args[1].shape == (0,) and args[0].size != 0:
+            return atleast_dims(args[0], axis)
 
     # Legacy behavior: if no axis is given, add a new axis at the front, and
     # glue along it
@@ -1652,7 +1656,8 @@ def glue(*args, **kwargs):
     # arrays to the same dimensionality. After this is done, ndims for all the
     # matrices will be the same, and np.concatenate() should know what to do.
     args = [ x[(np.newaxis,)*(max_ndim - x.ndim) + (Ellipsis,)] for x in args ]
-    return np.concatenate( args, axis=axis )
+    return atleast_dims(np.concatenate( args, axis=axis ),
+                        axis)
 
 
 def cat(*args):
@@ -2341,11 +2346,8 @@ def matmult2(a, b, out=None):
         array([[20, 23, 26, 29],
                [56, 68, 80, 92]])
 
-    This multiplies exactly 2 matrices, and the output object can be given in
-    the 'out' argument. If the usual case where the you let numpysane create and
-    return the result, you can use numpysane.matmult() instead. An advantage of
-    that function is that it can multiply an arbitrary N matrices together, not
-    just 2.
+    This function is exposed publically mostly for legacy compatibility. Use
+    numpysane.matmult() instead
 
     '''
 
@@ -2380,7 +2382,7 @@ def matmult2(a, b, out=None):
     o = np.matmul(a,b, out)
     return o
 
-def matmult( *args ):
+def matmult( a, *rest, **kwargs ):
     r'''Multiplication of N matrices
 
     SYNOPSIS
@@ -2411,14 +2413,33 @@ def matmult( *args ):
         array([[162],
                [504]])
 
+        >>> abc = np.zeros((2,1), dtype=float)
+        >>> nps.matmult(a,b,c, out=abc)
+        >>> abc
+        array([[162],
+               [504]])
+
     This multiplies N matrices together by repeatedly calling matmult2() for
-    each adjacent pair. Unlike matmult2(), the 'out' kwarg for the output is not
-    supported here.
+    each adjacent pair. In-place output is supported with the 'out' keyword
+    argument
 
     This function supports broadcasting fully, in C internally
 
     '''
-    return reduce( matmult2, args )
+
+    if len(rest) == 0:
+        raise Exception("Need at least two terms to multiply")
+
+    out = None
+    if len(kwargs.keys()) > 1:
+        raise Exception("Only ONE kwarg is supported: 'out'")
+    if kwargs:
+        # have exactly one kwarg
+        if 'out' not in kwargs:
+            raise Exception("The only supported kwarg is 'out'")
+        out = kwargs['out']
+
+    return matmult2(a,reduce(matmult2, rest), out=out)
 
 
 
