@@ -831,13 +831,15 @@ def test_concatenation():
     assertValueShape( None, (0,),      nps.glue, arr(0,),  arr(0,),      axis=-1 )
     assertValueShape( None, (2,),      nps.glue, arr(2,),  arr(0,),      axis=-1 )
     assertValueShape( None, (2,),      nps.glue, arr(0,),  arr(2,),      axis=-1 )
-    confirm_raises(   lambda: nps.glue( arr(2,),  arr(0,), axis=-2 ) )
-    assertValueShape( None, (2,),      nps.glue, arr(0,),  arr(2,),      axis=-2 )
+    assertValueShape( None, (1,2,),    nps.glue, arr(0,),  arr(2,),      axis=-2 )
 
     # same as before, but np.array(()) instead of np.arange(0)
     assertValueShape( None, (0,),      nps.glue, np.array(()), np.array(()), axis=-1 )
     assertValueShape( None, (2,),      nps.glue, arr(2,),  np.array(()), axis=-1 )
     assertValueShape( None, (2,),      nps.glue, np.array(()),arr(2,),   axis=-1 )
+    assertValueShape( None, (1,2),     nps.glue, np.array(()),arr(2,),   axis=-2 )
+    assertValueShape( None, (5,7),     nps.glue, np.array(()),arr(5,7),  axis=-2 )
+    assertValueShape( None, (5,7),     nps.glue, arr(5,7),    np.array(()),axis=-2 )
 
     assertValueShape( None, (0,6),     nps.glue, arr(0,3), arr(0,3),     axis=-1 )
     assertValueShape( None, (0,3),     nps.glue, arr(0,3), arr(0,3),     axis=-2 )
@@ -1168,25 +1170,24 @@ def test_matmult():
     assertResult_inoutplace(ref2,
                              nps.matmult2, arr(2,1,2,4), nps.matmult2(arr(2,4,3), arr(3,1)))
 
-    # not doing assertResult_inoutplace() because matmult() doesn't take an
-    # 'out' kwarg
-    confirm_equal(ref2,
-                  nps.matmult(arr(2,1,2,4), arr(2,4,3), arr(3,1)))
+    assertResult_inoutplace(ref2,
+                            nps.matmult,
+                            arr(2,1,2,4), arr(2,4,3), arr(3,1))
 
     # checking the null-dimensionality logic
     A = arr(2,3)
     assertResult_inoutplace( nps.inner(nps.transpose(A), np.arange(2)),
-                             nps.matmult2,
+                             nps.matmult,
                              np.arange(2), A )
 
     A = arr(3)
     assertResult_inoutplace( A*2,
-                             nps.matmult2,
+                             nps.matmult,
                              np.array([2]), A )
 
     A = arr(3)
     assertResult_inoutplace( A*2,
-                             nps.matmult2,
+                             nps.matmult,
                              np.array(2), A )
 
 
